@@ -67,6 +67,8 @@ class Device:
         self.trip_end_country = None
         self.trip_end_time = None
         self.trip_distance = None
+        self.trip_start_address = None
+        self.trip_end_address = None
         self.last_seen = None
         self.location_name = None
 
@@ -99,13 +101,15 @@ class Device:
             "odo": self.odo,
             "speed": self.speed,
             "trip_start_time": self.trip_start_time,
-            "trip_start_street": self.trip_start_street,
-            "trip_start_city": self.trip_start_city,
-            "trip_start_country": self.trip_start_country,
+            "trip_start_address": self.trip_start_address,
+            # "trip_start_street": self.trip_start_street,
+            # "trip_start_city": self.trip_start_city,
+            # "trip_start_country": self.trip_start_country,
             "trip_end_time": self.trip_end_time,
-            "trip_end_street": self.trip_end_street,
-            "trip_end_city": self.trip_end_city,
-            "trip_end_country": self.trip_end_country,
+            # "trip_end_street": self.trip_end_street,
+            # "trip_end_city": self.trip_end_city,
+            # "trip_end_country": self.trip_end_country,
+            "trip_end_address": self.trip_end_address,
             "trip_distance": self.trip_distance,
             "last_seen": self.trip_end_time,
             "location_name": self.location_name,
@@ -138,17 +142,22 @@ class Device:
             self.trip_start_time = self.getvalue(trip[-1], "startDate")
             self.trip_start_street = self.getvalue(trip[-1], "startRoad")
             self.trip_start_city = self.getvalue(trip[-1], "startCity")
+            self.trip_start_city = self.trip_start_city.replace("|m:", " ")
             self.trip_start_country = self.getvalue(trip[-1], "startCountry")
 
             self.trip_end_time = self.getvalue(trip[-1], "endDate")
             self.trip_end_street = self.getvalue(trip[-1], "endRoad")
             self.trip_end_city = self.getvalue(trip[-1], "endCity")
+            self.trip_end_city = self.trip_end_city.replace("|m:", " ")
             self.trip_end_country = self.getvalue(trip[-1], "endCountry")
 
             self.trip_distance = self.getvalue(trip[-1], "distance") / 1000
             self.trip_end_time = self.converttime(self.getvalue(trip[-1], "endDate"))
             self.location_name = self.getvalue(trip[-1], "endAlias")
 
+            self.trip_start_address = f"{self.trip_start_street}, {self.trip_start_city}, {self.trip_start_country}"
+            self.trip_end_address = f"{self.trip_end_street}, {self.trip_end_city}, {self.trip_end_country}"
+
     @staticmethod
     def getvalue(data, value):
         """Safely get values."""
