@@ -109,12 +109,12 @@ class Utilities:
                 message = json_payload.get("message")
                 if status == "UNAUTHORIZED":
                     pass
-
-                _LOGGER.error(
-                    "Error occurred %s %s",
-                    response.status_code,
-                    message,
-                )
+                else:
+                    _LOGGER.debug(
+                        "Error occurred %s %s",
+                        response.status_code,
+                        message,
+                    )
         except Timeout:
             _LOGGER.error(
                 "Connection timed out occurred. Possible connectivity outage.",
